@@ -3,7 +3,6 @@ use crate::app::keys::{KeyBinding, KEY_BINDINGS};
 use crate::app::mode::Mode;
 use crate::app::prompt::{OutputType, Prompt, COMMAND_PREFIX, SEARCH_PREFIX};
 use crate::app::selection::Selection;
-use crate::app::splash::{SplashConfig, SplashScreen};
 use crate::app::state::State;
 use crate::app::style::Style;
 use crate::app::tab::Tab;
@@ -20,6 +19,7 @@ use colorsys::Rgb;
 use copypasta_ext::display::DisplayServer as ClipboardDisplayServer;
 use copypasta_ext::ClipboardProviderExt;
 use ratatui::style::Color;
+use ratatui_splash_screen::{SplashConfig, SplashScreen};
 use std::collections::HashMap;
 use std::path::Path;
 use std::process::Command as OsCommand;
@@ -32,11 +32,12 @@ const MESSAGE_DURATION: u128 = 1750;
 
 /// Splash screen config.
 static SPLASH_CONFIG: SplashConfig = SplashConfig {
-	image_path: "splash.jpg",
-	sha256_hash: Some(hex_literal::hex!(
-		"dffd680d649a4a4b5df25dc1afaa722186c3bf38469a9156bad33f1719574e2a"
-	)),
+	image_data: include_bytes!("../../assets/splash.jpg"),
+	sha256sum: Some(
+		"dffd680d649a4a4b5df25dc1afaa722186c3bf38469a9156bad33f1719574e2a",
+	),
 	render_steps: 12,
+	use_colors: true,
 };
 
 /// Main application.
@@ -105,7 +106,7 @@ impl<'a> App<'a> {
 			keys_table_margin: 1,
 			clipboard: match ClipboardDisplayServer::select().try_context() {
 				None => {
-					eprintln!("failed to initialize clipboard, no suitable clipboard provider found");
+					log::error!("failed to initialize clipboard, no suitable clipboard provider found");
 					None
 				}
 				clipboard => clipboard,
@@ -482,6 +483,7 @@ impl<'a> App<'a> {
 					Command::RefreshKeys => os_command.arg("--refresh-keys"),
 					_ => os_command.arg("--full-gen-key"),
 				};
+				log::debug!(target: "cmd", "running OS command: {os_command:?}");
 				match os_command.spawn() {
 					Ok(mut child) => {
 						child.wait()?;
@@ -953,6 +955,12 @@ impl<'a> App<'a> {
 			Command::PreviousTab => {
 				self.run_command(self.tab.previous().get_command())?
 			}
+			Command::Logs => {
+				self.state.show_logs = !self.state.show_logs;
+			}
+			Command::LoggerEvent(event) => {
+				self.state.logger_state.transition(event.0);
+			}
 			Command::Refresh => self.refresh()?,
 			Command::Quit => self.state.running = false,
 			Command::Confirm(_) | Command::None => {}
