@@ -5,24 +5,23 @@ use crate::app::style;
 use crate::app::tab::Tab;
 use crate::widget::row::RowItem;
 use crate::widget::table::TableSize;
-use ratatui::backend::Backend;
 use ratatui::layout::{Alignment, Constraint, Direction, Layout, Rect};
 use ratatui::style::{Color, Modifier, Style};
 use ratatui::terminal::Frame;
 use ratatui::text::{Line, Span, Text};
-use ratatui::widgets::canvas::{Canvas, Points};
 use ratatui::widgets::{
 	Block, Borders, Clear, List, ListItem, Paragraph, Row, Table, Wrap,
 };
 use std::cmp;
 use std::convert::{TryFrom, TryInto};
+use tui_logger::{TuiLoggerLevelOutput, TuiLoggerSmartWidget};
 use unicode_width::UnicodeWidthStr;
 
 /// Lengths of keys row in minimized/normal mode.
 const KEYS_ROW_LENGTH: (u16, u16) = (31, 55);
 
 /// Renders all the widgets thus the user interface.
-pub fn render<B: Backend>(app: &mut App, frame: &mut Frame<'_, B>) {
+pub fn render(app: &mut App, frame: &mut Frame) {
 	let rect = frame.size();
 	if app.keys_table.state.minimize_threshold != 0 {
 		app.keys_table.state.size.set_minimized(
@@ -30,63 +29,66 @@ pub fn render<B: Backend>(app: &mut App, frame: &mut Frame<'_, B>) {
 		);
 	}
 	if app.state.show_splash {
-		render_splash_screen(app, frame, rect);
+		frame.render_widget(&mut app.splash_screen, rect);
+		app.state.show_splash = !app.splash_screen.is_rendered();
 	} else {
+		let mut main_rect = rect;
+		if app.state.show_logs {
+			let chunks = Layout::default()
+				.direction(Direction::Vertical)
+				.constraints([
+					Constraint::Percentage(60),
+					Constraint::Percentage(40),
+				])
+				.split(rect);
+			render_log_view(app, frame, chunks[1]);
+			main_rect = chunks[0];
+		}
 		let chunks = Layout::default()
 			.direction(Direction::Vertical)
 			.constraints(
-				[Constraint::Min(rect.height - 1), Constraint::Min(1)].as_ref(),
+				[Constraint::Min(main_rect.height - 1), Constraint::Min(1)]
+					.as_ref(),
 			)
-			.split(rect);
+			.split(main_rect);
 		render_command_prompt(app, frame, chunks[1]);
 		match app.tab {
 			Tab::Keys(_) => render_keys_table(app, frame, chunks[0]),
 			Tab::Help => render_help_tab(app, frame, chunks[0]),
 		}
 		if app.state.show_options {
-			render_options_menu(app, frame, rect);
+			render_options_menu(app, frame, main_rect);
 		}
 	}
 }
 
-/// Renders the splash screen.
-fn render_splash_screen<B: Backend>(
-	app: &mut App,
-	frame: &mut Frame<'_, B>,
-	rect: Rect,
-) {
-	app.state.show_splash = app.splash_screen.step != 0;
-	let data = app.splash_screen.get(app.state.style.is_colored());
-	frame.render_widget(
-		Canvas::default()
-			.x_bounds([
-				0.0,
-				(app.splash_screen.image.to_rgb8().width() - 1) as f64,
-			])
-			.y_bounds([
-				0.0,
-				(app.splash_screen.image.to_rgb8().height() - 1) as f64,
-			])
-			.paint(|p| {
-				for rgb in data.keys() {
-					if let Some(coords) = data.get(rgb) {
-						p.draw(&Points {
-							coords,
-							color: Color::Rgb(rgb.0, rgb.1, rgb.2),
-						})
-					}
-				}
-			}),
-		rect,
-	);
+/// Renders the log view.
+fn render_log_view(app: &mut App, frame: &mut Frame, rect: Rect) {
+	let logger_widget = TuiLoggerSmartWidget::default()
+		.style_trace(Style::default().fg(Color::DarkGray))
+		.style_debug(Style::default().fg(Color::Blue))
+		.style_warn(Style::default().fg(Color::Yellow))
+		.style_error(Style::default().fg(Color::Red))
+		.style_info(Style::default().fg(Color::Green))
+		.highlight_style(if app.state.style.is_colored() {
+			Style::default().add_modifier(Modifier::BOLD)
+		} else {
+			Style::default()
+				.fg(Color::Reset)
+				.add_modifier(Modifier::BOLD)
+		})
+		.output_separator(':')
+		.output_timestamp(Some("%H:%M:%S".to_string()))
+		.output_level(Some(TuiLoggerLevelOutput::Long))
+		.output_target(true)
+		.output_file(true)
+		.output_line(true)
+		.state(&app.state.logger_state);
+	frame.render_widget(logger_widget, rect);
 }
 
 /// Renders the command prompt.
-fn render_command_prompt<B: Backend>(
-	app: &mut App,
-	frame: &mut Frame<'_, B>,
-	rect: Rect,
-) {
+fn render_command_prompt(app: &mut App, frame: &mut Frame, rect: Rect) {
 	frame.render_widget(
 		Paragraph::new(Line::from(if !app.prompt.text.is_empty() {
 			vec![Span::raw(format!(
@@ -165,11 +167,7 @@ fn render_command_prompt<B: Backend>(
 }
 
 /// Renders the help tab.
-fn render_help_tab<B: Backend>(
-	app: &mut App,
-	frame: &mut Frame<'_, B>,
-	rect: Rect,
-) {
+fn render_help_tab(app: &mut App, frame: &mut Frame, rect: Rect) {
 	frame.render_widget(
 		Block::default()
 			.borders(Borders::ALL)
@@ -323,11 +321,7 @@ fn render_help_tab<B: Backend>(
 }
 
 /// Renders the options menu.
-fn render_options_menu<B: Backend>(
-	app: &mut App,
-	frame: &mut Frame<'_, B>,
-	rect: Rect,
-) {
+fn render_options_menu(app: &mut App, frame: &mut Frame, rect: Rect) {
 	let items = app
 		.options
 		.items
@@ -394,24 +388,26 @@ fn render_options_menu<B: Backend>(
 }
 
 /// Renders the table of keys.
-fn render_keys_table<B: Backend>(
-	app: &mut App,
-	frame: &mut Frame<'_, B>,
-	rect: Rect,
-) {
+fn render_keys_table(app: &mut App, frame: &mut Frame, rect: Rect) {
 	let keys_row_length = if app.keys_table.state.size != TableSize::Normal {
 		KEYS_ROW_LENGTH.0
 	} else {
 		KEYS_ROW_LENGTH.1
 	};
 	frame.render_stateful_widget(
-		Table::new(get_keys_table_rows(
-			app,
-			rect.width
-				.checked_sub(keys_row_length + 7)
-				.unwrap_or(rect.width),
-			rect.height.checked_sub(2).unwrap_or(rect.height),
-		))
+		Table::new(
+			get_keys_table_rows(
+				app,
+				rect.width
+					.checked_sub(keys_row_length + 7)
+					.unwrap_or(rect.width),
+				rect.height.checked_sub(2).unwrap_or(rect.height),
+			),
+			&[
+				Constraint::Min(keys_row_length),
+				Constraint::Percentage(100),
+			],
+		)
 		.style(Style::default().fg(app.state.color))
 		.highlight_style(if app.state.style.is_colored() {
 			Style::default().add_modifier(Modifier::BOLD)
@@ -426,10 +422,6 @@ fn render_keys_table<B: Backend>(
 				.borders(Borders::ALL)
 				.border_style(Style::default().fg(Color::DarkGray)),
 		)
-		.widths(&[
-			Constraint::Min(keys_row_length),
-			Constraint::Percentage(100),
-		])
 		.column_spacing(1),
 		rect,
 		&mut app.keys_table.state.tui,
@@ -527,7 +519,7 @@ mod tests {
 	use crate::gpg::key::KeyType;
 	use anyhow::Result;
 	use pretty_assertions::assert_eq;
-	use ratatui::backend::TestBackend;
+	use ratatui::backend::{Backend, TestBackend};
 	use ratatui::buffer::Buffer;
 	use ratatui::Terminal;
 	use std::env;
@@ -614,8 +606,8 @@ mod tests {
 			"│                                │                                   │",
 			&format!("│ Use arrow keys / hjkl to       │  {}            │", gpg_info[1].trim()),
 			&format!("│ navigate through the key       │  {}          │", gpg_info[2].trim()),
-			&format!("│ bindings.                      │  {}     │", gpg_info[3].trim()),
-			&format!("│ Corresponding commands and     │  {}     │", &gpg_info[4][0..32].trim()),
+			&format!("│ bindings.                      │  {}      │", gpg_info[3].trim()),
+			&format!("│ Corresponding commands and     │  {}      │", &gpg_info[4][0..32].trim()),
 			"│                                                                    │",
 			"└────────────────────────────────────────────────────────────────────┘",
 			"                                                              < help >",
@@ -624,7 +616,7 @@ mod tests {
 					Some(pos) => format!("{}{}", &line[..pos], line.chars().last().unwrap_or_default()),
 					None => line.to_string(),
 				}
-			}).collect()),
+			}).collect::<Vec<String>>()),
 			&terminal,
 		);
 		Ok(())
